# Path Animation

SVG path following, stroke trim clips, and path morphing.

## follow_path

::: pymotion.path_animation.follow_path

## StrokeClip

::: pymotion.path_animation.StrokeClip

## morph_paths

::: pymotion.path_animation.morph_paths
